capture log close
log using wfauto-03macros, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s2manual

//  Guide to Automating Your Work in Stata
//  Scott Long & Bianca Manago
//  local macros

local pgm wfauto-03macros-bmedits
local dte 2015-05-13
local who scott long
local tag "`pgm' `who' `dte'"

//  load data

use wf-lfp, clear

//  #1 Local Macros

local varlist "lfp k5 k618 age wc hc lwg inc"
di "The local varlist contains: `varlist'"

summarize `varlist'

//  #2 creating long strings

local hardshipvars "hsphone hsmortg hsevict hsutil hsmedical hsdoctor"
local hardshipvars "`hardshipvars' hsdentist hsrent hsfood"
di "`hardshipvars'"

//  #3 Setting options with locals

local opt_tab "cell miss nolabel chi2"
tabulate wc hc, `opt_tab'
tabulate wc lfp, `opt_tab'

//  #4 Using locals for formatting

* C == column
local C1 = 5    // set 1 begins at 5
local C2 = 20
local C3 = 30

* W == width
local W2 = 10   // width of both columns to be 10
local W3 = 10

* D == decimal
local D2 = 2    // set 2 has 2 decimal places
local D3 = 3    // set 3 has 3 decimal places

* display our results

di _col(`C1') "age" ///
   _col(`C2') "Mean = " %-`W2'.`D2'f  1.23328924 ///
   _col(`C3') "SD = "   %-`W3'.`D3'f  23.4256

//  #5 Extended macros

local varnm "age"
local varlbl : variable label `varnm'
display "The label for `varnm' is: `varlbl'"

log close
exit
