capture log close
log using wflec-add-examples, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s1manual

//  WF lectures: adding - examples

local pgm wflec-add-examples
local dte 2017-06-19
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 changing the meaning of a variable

use wf-lfp, clear

* lwg equal to the log of wages
logit lfp k5 k618 age wc hc lwg inc
estimates store model_1

* lwg equal to wages
replace lwg = exp(lwg)
logit lfp k5 k618 age wc hc lwg
estimates store model_2

* compare models
estimates table _all, stats(N bic) eform b(%9.3f) t(%6.2f)

//  #2 log of a negative number -- should it automatically be made missing?

use wf-lfp, clear
generate inclog = log(inc)
label var inclog "log(inc)"
list inc inclog if inc<0, clean

//  #3 documenting new variables

use wf-lfp, clear
generate inc_log5 = ln(inc+.5) if !missing(inc)
label var inc_log5 "Log(inc+.5)"
note inc_log5: log(inc+.5) / `tag'

//  #4 the generate command

use wf-lfp, clear

* transform all values of age
generate agesqrt = sqrt(age)
label var agesqrt "Sqrt(age)"
drop agesqrt

* transform only values of age greater than 5
generate agesqrt = sqrt(age) if age>5
label var agesqrt "Sqrt(age) if age>5"

//  #5 clonevar

use wf-lfp, clear

* create a copy of lfp using generate
generate lfp_gen = lfp

* create a copy using clonevar
clonevar lfp_clone = lfp

* compare original to clone
summarize lfp*
describe lfp*
compare lfp lfp_gen
compare lfp lfp_clone

//  #6 replace

use wf-russia01, clear

generate educcat = edyears
label var educcat "Categorized years of education"
replace educcat = 1 if edyears>=0  & edyears<=8   // no HS
replace educcat = 2 if edyears>=9  & edyears<=11  // some HS
replace educcat = 3 if edyears==12                // HS
replace educcat = 4 if edyears>=13 & edyears<=15  // some college
replace educcat = 5 if edyears>=16 & edyears<=24  // college plus

label def educcat 1 1_NoHS 2 2_someHS 3 3_HS 4 4_someCol 5 5_ColPlus ///
     .b b_Refused .c c_DontKnow .d d_AtSchool .e e_AtCollege ///
     .f f_NoFrmlSchl
label val educcat educcat
tab1 edyears educcat, missing

//  #7 problem with missing values

use wf-russia01, clear

tab1 marstat, miss

* incorrect
generate ismar_wrong = (marstat==1)
label var ismar_wrong "Is married created incorrectly"
label def Lyesno 0 0_no 1 1_yes
label val ismar_wrong Lyesno
tabulate marstat ismar_wrong, miss

* correct
generate ismar_right = (marstat==1) if !missing(marstat)
label var ismar_right "Is married?"
label val ismar_right Lyesno
tabulate marstat ismar_right, miss

* fixing the extended missing value
replace ismar_right = .b if marstat==.b
tabulate marstat ismar_right, miss

//  #8 recode

* dichotmize marstat
recode marstat 1=1 2/5=0, gen(ismar2_right)
label var ismar2_right "Is married?"
tabulate marstat ismar2_right, miss

* ed categories with recode instead of replace
recode edyears 0/8=1 9/11=2 12=3 13/15=4 16/24=5, gen(educcat2)
compare educcat educcat2
tabulate educcat educcat2, miss

* recode 1 to 0 and change all other values (including missing) to 1
recode edyears 1=0 *=1, gen(edtest1)
tabulate edyears edtest1, miss

* recode 1 to 0, else 1 except for missing
recode edyears 1=0 *=1 if !missing(edyears), gen(edtest2)
tabulate edyears edtest2, miss

* keep 1, 2, 3, 4, 5 the same; recode 6-24 to 6, except missing
recode edyears 6/24=6 if !missing(edyears), gen(edtest3)
tabulate edyears edtest3, miss

* recode 1 3 5 7 9 to -1, others unchanged
recode edyears 1 3 5 7 9=-1, gen(edtest4)
tabulate edyears edtest4, miss

* recode 6 to max to 6, others unchanged
recode edyears 6/max=6, gen(edtest5)
tabulate edyears edtest5, miss

//  #9 egen to standardize age

use wf-lfp, clear

* standardize using generate and summarize
summarize age
generate agestd = (age - r(mean)) / r(sd)
label var agestd "Age standardized using generate"

* use egen std
egen agestdV2 = std(age)
label var agestdV2 "Age standardized using egen"

* compare
compare agestd agestdV2
summarize agestd agestdV2
regress agestdV2 agestd

//  #10 egen anycount

* anycount(varlist), values(integer numlist): returns the number of
*   variables in varlist for which values are equal to any of the integer
*   values in a supplied numlist. Values for any observations excluded
*   by either [if] or [in] are set to 0 (not missing).

egen count0 = anycount(lfp k5 k618 age wc hc lwg inc), values(0)
label var count0 "# of 0's in lfp k5 k618 age wc hc lwg inc"
tabulate count0, miss

* computing the same thing with a foreach loop
generate count0v2 = 0
label var count0v2 "v2:# of 0's in lfp k5 k618 age wc hc lwg inc"
foreach var in lfp k5 k618 age wc hc lwg inc {
    replace count0v2 = count0v2 + 1 if `var'==0
}

compare count0 count0v2

//  #11 tabulate, generate

use wf-russia01, clear

tabulate marstat, gen(ms_is)

codebook ms_is*, compact
describe ms_is*
summarize ms_is*
tabulate marstat ms_is1, miss

* clean up the variables
label def Lyesno 0 0_no 1 1_yes

rename ms_is1 ms_married
note ms_married: Source var is marstat / `tag'
label var ms_married "Married?"
label val ms_married Lyesno
tabulate marstat ms_married, miss

rename ms_is2 ms_widowed
note ms_widowed: Source var is marstat / `tag'
label var ms_widowed "Widowed?"
label val ms_widowed Lyesno
tabulate marstat ms_widowed, miss

rename ms_is3 ms_divorced
note ms_divorced: Source var is marstat / `tag'
label var ms_divorced "Divorced?"
label val ms_divorced Lyesno
tabulate marstat ms_divorced, miss

rename ms_is4 ms_separated
note ms_separated: Source var is marstat / `tag'
label var ms_separated "Seperated?"
label val ms_separated Lyesno
tabulate marstat ms_separated, miss

rename ms_is5 ms_single
note ms_single: Source var is marstat / `tag'
label var ms_single "Single?"
label val ms_single Lyesno
tabulate marstat ms_single, miss

notes ms_*

* easy way to check for problems with the indicators
regress ms_married ms_widowed ms_divorced ms_separated ms_single

// verifying new variables ==================================================

use wf-verify, clear

//  #11 listing values

* recodes fincome to the midpoint of the range
generate finc_mid = fincome
label var finc_mid "Income coded at the midpoint"
note finc_mid: midpoints for fincome; high value is 1.25x truncation value / `tag'
recode finc_mid ///
     1=1.5   2=4     3=6     4=8     5=9.5   6=10.5  7=11.5  8=12.5   ///
     9=13.5 10=14.5 11=16   12=18.5 13=21   14=23.5 15=23.5 16=32.5   ///
    17=37.5 18=42.5 19=47.5 20=55   21=67.5 22=82.5 23=97.5 24=131.25

set seed 1951
tempvar selvar
generate `selvar' = int( (runiform()*_N)+ 1 )
label var `selvar' "Temporary: random numbers from 1 to _N"
summarize `selvar' // verify range

sort fincome
list fincome finc_mid if `selvar'<20, clean

//  #12 by: sum

sort finc_mid
by finc_mid: sum fincome

//  #13 plotting midpoint variable

scatter fincome finc_mid, msymbol(circle_hollow)
graph export `pgm'-verify-finc_mid.emf, replace

//  #14 plot continuous variable plot

generate inc_sqrt = sqrt(inc) if !missing(inc)
label var inc_sqrt "Square root of inc"

scatter inc_sqrt inc, msymbol(circle_hollow)
graph export `pgm'-verify-inc_sqrt.emf, replace

//  #15 checking missing values with tabulate

use wf-verify, clear

generate inc_sqrt = sqrt(inc)
label var inc_sqrt "Square root family income excluding wife's"
tabulate inc inc_sqrt if missing(inc) | missing(inc_sqrt), miss

//  #16 compare two ways of creating the same variable

* use recode
recode edyears 0/8=1 9/11=2 12=3 13/15=4 16/24=5, gen(educcat)

* create variable with gen and replace
generate educcatV2 = edyears
replace educcatV2 = 1 if edyears>=0  & edyears<=8   // no HS
replace educcatV2 = 2 if edyears>=9  & edyears<=11  // some HS
replace educcatV2 = 3 if edyears==12                // HS
replace educcatV2 = 4 if edyears>=13 & edyears<=15  // some college
replace educcatV2 = 5 if edyears>=16 & edyears<=24  // college plus
label var educcatV2 "categorize educ using replace"

compare educcat educcatV2

log close
exit
