capture log close
log using wflec-analysis-collect-transforms, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: analysis - collect results for different transformations

local pgm wflec-analysis-collect-transforms
local dte 2017-06-19
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 load data and select sample

use wf-tenure, clear
datasignature confirm
keep if sampleis

//  #2 create art_root# = (articles)^(1/#)
//  NOTE: best practice would do this with tempvars!

local artvars "" // list of variables to test
forvalues root = 1(1)9 { // loop through each root
    * take to the 1/root power
    gen art_root`root' = articles^(1/`root')
    label var art_root`root' "articles^(1/`root')"
    * add new variable to the list
    local artvars "`artvars' art_root`root'"
}

//  #3 loop through models

capture matrix drop matart

local iroot = 0
foreach artvar in `artvars' {
    local ++iroot
    quietly sum `artvar'
    scalar sdev = r(sd)
    quietly logit tenure `artvar' female year yearsq select prestige, nolog
    scalar b = _b[`artvar']
    scalar bstd = b*sdev
    scalar ebstd = exp(bstd)
    quietly estat ic
    scalar ic = el(r(S),1,6)
    matrix matart = nullmat(matart) \ (`iroot', sdev, bstd, ebstd, ic)
}
matrix colnames matart = Root sd b_std exp_b_std bic
matrix rownames matart = `artvars'

//  #4 print summary of results

local header "Comparing root transformations of articles in logit"
* NOTE: model also includes female year yearsq select prestige
matlist matart, format(%9.3f) title(`header')

//  #5 save results to plot

drop _all
svmat matart, names(col)
compress
label data "`pgm'.do | `dte'"
note: `pgm'.dta / `dte'
datasignature set
saveold `pgm', replace

log close
exit

