capture log close
log using wflec-analysis-collect-ttest, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: analysis - collect ttest results

local pgm wflec-analysis-collect-ttest
local dte 2017-06-19
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 load data and select sample

use wf-tenure, clear
datasignature confirm
keep if sampleis

//  #2 multiple ttests

ttest tenure,   by(female)
ttest year,     by(female)
ttest select,   by(female)
ttest articles, by(female)
ttest prestige, by(female)

local varlist "tenure year select articles prestige"
foreach var in `varlist' {
    di _new ". ttest `var', by(female)"
    ttest `var', by(female)
}

//  #3 examine what ttest returns

ttest tenure, by(female)
return list

//  #4 ttest of gender differences with matrices

local varlist "tenure year select articles prestige"

* matrix to hold results
capture matrix drop ttestresults // get rid of matrix
local ncols = 6
matrix vecorig = J(1,`ncols',-999)
matrix colnames vecorig = Wmn Wsd Mmn Msd ttest Prob

* collect information
foreach var in `varlist' {
    quietly ttest `var', by(female)
    mat myvec = vecorig
    mat myvec[1,1] = r(mu_2)
    mat myvec[1,2] = r(sd_2)
    mat myvec[1,3] = r(mu_1)
    mat myvec[1,4] = r(sd_1)
    mat myvec[1,5] = r(t)
    mat myvec[1,6] = r(p)
    mat rownames myvec = `var'
    mat ttestresults = nullmat(ttestresults) \ myvec
}

* list resutls
local n_men = r(N_1)
local n_women = r(N_2)
local header "t-tests: mean_women (N=`n_women') = mean_men (N=`n_men')"

matlist ttestresults, title(`header') format(%8.3f)

log close
exit
