capture log close
log using wflec-auto-macros, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: automation - macros

local pgm wflec-auto-macros
local dte 2017-06-21
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  display ==================================================================

di _n "`tag'"

display "DOG"
di "Workflow, not slow. --Bruce Frasier"

di 1 + 2
display 2*3
di exp(cos(2^4))

di normal(0)
di normal(2)
di normal(-2)

//  macros ===================================================================

local rhsvars "var1 var2 var3 var4"
di "`rhsvars'"

local ncases = 198
di "ncases: `ncases'"

local moptions "msym(square circle) mcol(red blue) jitter(5)"
di "myoptions: `moptions'"

//  building a long string

local demvars "female black hispanic age agesq"
di "demvars:`demvars'"
local demvars "`demvars' edHS edcol edpost"
di "demvars:`demvars'"
local demvars "`demvars' incdollars childsqrt"
di "demvars:`demvars'"

* or
local demvars female black hispanic age agesq ///
edHS edcol edpost incdollars childsqrt
di "demvars: `demvars'"

//  tabulate options

use wf-lfp
local opt_tab "cell miss nolabel chi2"
tabulate wc hc, `opt_tab'
tabulate wc lfp, `opt_tab'

local opt_tab "row miss nolabel chi2"
tabulate wc hc, `opt_tab'
tabulate wc lfp, `opt_tab'

//  change variables

use wf-lfp
summarize lfp k5 k618 age wc hc lwg inc
logit     lfp k5 k618 age wc hc lwg inc

summarize lfp k5 k618 age wc lwg inc
logit     lfp k5 k618 age wc lwg inc

local myvars "lfp k5 k618 age wc hc lwg inc"
summarize `myvars'
logit     `myvars'

local myvars "lfp k5 k618 age wc lwg inc"
summarize `myvars'
logit     `myvars'

//  model specification

summarize lfp k5 k618 age wc hc lwg inc
logit     lfp k5 k618 age wc hc lwg inc

gen agesq = age*age

summarize lfp k5 k618 age agesq wc lwg inc
logit     lfp k5 k618 age agesq wc lwg inc

local myvars "lfp k5 k618 age wc hc lwg inc"
summarize `myvars'
logit     `myvars'

local myvars "lfp k5 k618 age       lwg inc"
summarize `myvars'
logit     `myvars'

//  nested models

local set1_age  "age agesq"
local set2_educ "wc hc"
local set3_kids "k5 k618"

display "set1_age:  `set1_age'"
display "set2_educ: `set2_educ'"
display "set3_kids: `set3_kids'"

* four nested models:
local model1 "`set1_age'"
local model2 "`model1' `set2_educ'"
local model3 "`model2' `set3_kids'"

display "model1: `model1'"
display "model2: `model2'"
display "model3: `model3'"

* estimate models
logit lfp `model1'
logit lfp `model2'
logit lfp `model3'

* only need one change to change age
local set1_age "age"

//  locals with graph

/*
  graph twoway ///
    (connected pr_women articles, lpat(solid) lwid(medthick) ///
        lcol(black) msym(i)) ///
    (connected pr_men articles,   lpat(dash)  lwid(medthick) ///
        lcol(black) msym(i)) ///
    , ylab(0(.2)1., grid glwid(medium) glpat(dash)) ///
      xlab(0(10)50) ytitle("Probability of tenure") ///
      legend(pos(11) order(2 1) ring(0) cols(1))
*/

* create locals with sets of options
local opt_linF "lpat(solid) lwid(medthick) lcol(black) msym(i)"
local opt_linM "lpat(dash)  lwid(medthick) lcol(black) msym(i)"
local opt_ygrid "grid glwid(medium) glpat(dash)"
local opt_legend "pos(11) order(2 1) ring(0) cols(1)"

* my graph command is

di  "graph twoway ///"
di  "  (connected pr_women articles, `opt_linF') ///"
di  "  (connected pr_men   articles, `opt_linM') ///"
di  " , xlab(0(10)50) ylab(0(.2)1., `opt_ygrid') ///"
di `"   ytitle("Probability of tenure") legend(`opt_legend')"'

* to use colored lines to distinguish between men and women
local opt_linF "lpat(solid) lwid(medthick) lcol(red)  msym(i)"
local opt_linM "lpat(dash)  lwid(medthick) lcol(blue) msym(i)"

//  global macros

global vars x1 x2 x3
di "$vars"

//  data on networks

* Data must be located here: q:\TXRDC\census2000\PUMS

* This makes the do-file fragile:
*    use \TXRDC\census2000\PUMS\file9112, clear

* Outside of the do-file, run:

global path "q:\TXRDC\census2000\PUMS\"
di "$path"

* Inside the do-file, do not drop macros with macro drop _all
* Then,

di "use ${path}file9112, clear"

global path "d:\My Documents\"
di `"use "${path}binlfp4", clear"'

log close
exit

DROP


* no robust
use g:\DogBox\Resources\Datasets\binlfp4.dta

* outsider of do-files
global path g:\DogBox\Resources\Datasets\

* inside
di "use ${path}binlfp4, clear"
use ${path}binlfp4, clear

* if path has blanks
global path g:\Box Sync\Stat612\Resources\Datasets\
di "${path}binlfp4"
use "${path}binlfp4", clear

macro drop _all
di `"${path}binlfp4"'
use "${path}binlfp4", clear


