capture log close
log using wflec-debug-precision, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: debug - unexpected results

local pgm wflec-debug-precision
local dte 2017-06-18
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 load data and look at basic information

use wf-flims, clear
summarize hnd hvy lft rch sit std stp str wlk

//  #2 combining two variables

generate strwlk = 10*str + wlk
tabulate strwlk, missing

//  #3 create variable containing all limitations

generate flimall = hnd*100000000 + hvy*10000000 + lft*1000000 ///
    + rch*100000 + sit*10000 + std*1000 + stp*100 + str*10 + wlk
label var flimall "hnd-hvy-lft-rch-sit-std-stp-str-wlk"
tabulate flimall, missing

//  #4 create a string version of all limitations

generate  sflimall=string(flimall, "%16.0f")
label var sflimall "hnd-hvy-lft-rch-sit-std-stp-str-wlk"
tabulate  sflimall, missing

//  #5 make the code easier to debug

use wf-flims, clear
generate flimall = hnd*100000000 ///
                 + hvy*10000000 ///
                 + lft*1000000 ///
                 + rch*100000 ///
                 + sit*10000 ///
                 + std*1000 ///
                 + stp*100 ///
                 + str*10 ///
                 + wlk
label var flimall "hnd-hvy-lft-rch-sit-std-stp-str-wlk"

//  #6 try a simpler example and make it easier to read

use wf-flims, clear
generate flimall = std*1000 ///
                 + stp*100 ///
                 + str*10 ///
                 + wlk
generate  sflimall=string(flimall,"%9.0f")
label var sflimall "std-stp-str-wlk"
tabulate  sflimall, missing

//  #7 keep adding one at a time till it breaks

use wf-flims, clear
generate flimall = hvy*10000000 ///
            + lft*1000000 ///
            + rch*100000 ///
            + sit*10000 ///
            + std*1000 ///
            + stp*100 ///
            + str*10 ///
            + wlk
generate  sflimall = string(flimall,"%09.0f")
label var sflimall "hvy-lft-rch-sit-std-stp-str-wlk"
tabulate  sflimall, missing

//  #8 look at a value that is a problem

list if sflimall == "111111112", clean

//  #9 fix the problem by using higher precisions

use wf-flims, clear
generate double flimall = hnd*100000000 ///
                        + hvy*10000000 ///
                        + lft*1000000 ///
                        + rch*100000 ///
                        + sit*10000 ///
                        + std*1000 ///
                        + stp*100 ///
                        + str*10 ///
                        + wlk
generate sflimall = string(flimall,"%09.0f")
tabulate sflimall, missing

//  #10 - alternative approach that only uses strings

use wf-flims, clear
foreach v in hnd hvy lft rch sit std stp str wlk {
    generate s`v' = string(`v',"%1.0f")
}
generate sflimall = shnd + shvy + slft + srch + ssit ///
    + sstd + sstp + sstr + swlk
    label var sflimall "hnd-hvy-lft-rch-sit-std-stp-str-wlk"
tabulate sflimall, missing

log close
exit