capture log close
log using wflec-dual-data05-binscales, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: dual workflow - data 05 binary scales

local pgm wflec-dual-data05-binscales
local dte 2017-06-16
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 setup

local srcdata wflec-dual-data03
local savdata wflec-dual-data04

use `srcdata', clear
datasignature confirm

local m1rhs female age married logfaminc
local m2rhs `m1rhs' highered fulltime
local m3rhs `m2rhs' momworks kidsnone
local regvars `m3rhs'

* require all rhs variables to be nonmissing
qui reg `regvars' // quick way to select listwise deletion sample
gen IRTsample = e(sample)

//  #2 check variables: note missing data

local vars BHwarm BHkidsuf BHfamsuf BHnotboth BHjobsat BHindep

codebook `vars' if IRTsample, compact
pwcorr   `vars' if IRTsample, obs

//  #3 summated Scale

alpha `vars' if IRTsample, gen(prowrkSS)
label var prowrkSS "Support working women: sumscale binary items"
sum prowrkSS
note prowrkSS: `tag'

//  #4 IRT 2pl

irt 2pl `vars' if IRTsample, intpoints(18) nolog // 2pl IRT
predict   prowrkIRT, latent
label var prowrkIRT "Support working women: IRT-2pl scores"
note prowrkIRT: `tag'

//  #4 save dataset

codebook female-prowrkIRT, compact // analysis variables

label data "`savdata'.dta | ISSP Russia 2002 Working Women | `dte'"
notes: `savdata'.dta | `tag' | scales from binary indicators
datasignature set, reset
save `savdata', replace
notes _dta

use `savdata', clear
datasignature confirm

* changes from soruce dataset
capture noisily cf _all using `srcdata'.dta, all

log close //
exit

